@@ -1,13 +1,15 @@
-# -*- coding: utf-8 -*-
 # flake8: noqa
+import pkg_resources
 import setoptconf as soc
-from prospector.__pkginfo__ import __version__
+
 from prospector.config.datatype import OutputChoice
 from prospector.formatters import FORMATTERS
-from prospector.tools import DEFAULT_TOOLS, TOOLS
+from prospector.tools import DEFAULT_TOOLS, DEPRECATED_TOOL_NAMES, TOOLS
 
 __all__ = ("build_manager",)
 
+_VERSION = pkg_resources.get_distribution("prospector").version
+
 
 def build_manager():
     manager = soc.ConfigurationManager("prospector")
@@ -28,6 +30,7 @@ def build_manager():
 
     manager.add(soc.BooleanSetting("messages_only", default=False))
     manager.add(soc.BooleanSetting("summary_only", default=False))
+    manager.add(soc.BooleanSetting("quiet", default=False))
     manager.add(
         soc.ListSetting(
             "output_format",
@@ -58,6 +61,7 @@ def build_manager():
     manager.add(soc.BooleanSetting("show_profile", default=False))
 
     manager.add(soc.BooleanSetting("no_external_config", default=False))
+    manager.add(soc.BooleanSetting("legacy_tool_names", default=False))
     manager.add(soc.StringSetting("pylint_config_file", default=None))
 
     manager.add(soc.StringSetting("path", default=None))
@@ -139,6 +143,10 @@ def build_command_line_source(prog=None, description="Performs static analysis o
             "flags": ["-T", "--test-warnings"],
             "help": "Also check test modules and packages.",
         },
+        "legacy_tool_names": {
+            "flags": ["--legacy-tool-names"],
+            "help": "Output deprecated names for tools (pep8, pep257) instead of updated names (pycodestyle, pydocstyle)",
+        },
         "no_style_warnings": {
             "flags": ["-8", "--no-style-warnings"],
             "help": "Don't create any warnings about style. This disables the"
@@ -150,9 +158,14 @@ def build_command_line_source(prog=None, description="Performs static analysis o
             "class or member of a module which does not exist. This is disabled "
             "by default as it tends to be quite inaccurate.",
         },
+        "quiet": {
+            "flags": ["-q", "--quiet"],
+            "help": "Run but do not output anything to stdout. Useful to suppress "
+            "output in scripts without sending to a file (via -o)",
+        },
         "full_pep8": {
             "flags": ["-F", "--full-pep8"],
-            "help": "Enables every PEP8 warning, so that all PEP8 style" " violations will be reported.",
+            "help": "Enables every PEP8 warning, so that all PEP8 style violation will be reported.",
         },
         "max_line_length": {
             "flags": ["--max-line-length"],
@@ -303,7 +316,7 @@ def build_command_line_source(prog=None, description="Performs static analysis o
 
     return soc.CommandLineSource(
         options=options,
-        version=__version__,
+        version=_VERSION,
         parser_options=parser_options,
         positional=positional,
     )
