@@ -1,8 +1,17 @@
 import os
+from typing import Dict, Optional, Union
 
 
-class Location(object):
-    def __init__(self, path, module, function, line, character, absolute_path=True):
+class Location:
+    def __init__(
+        self,
+        path: str,
+        module: Optional[str],
+        function: Optional[str],
+        line: int,
+        character: int,
+        absolute_path: bool = True,
+    ):
         self.path = path
         self._path_is_absolute = absolute_path
         self.module = module or None
@@ -10,19 +19,19 @@ class Location(object):
         self.line = None if line == -1 else line
         self.character = None if character == -1 else character
 
-    def to_absolute_path(self, root):
+    def to_absolute_path(self, root: str):  # TODO: use pathlib?
         if self._path_is_absolute:
             return
         self.path = os.path.abspath(os.path.join(root, self.path))
         self._path_is_absolute = True
 
-    def to_relative_path(self, root):
+    def to_relative_path(self, root: str):
         if not self._path_is_absolute:
             return
         self.path = os.path.relpath(self.path, root)
         self._path_is_absolute = False
 
-    def as_dict(self):
+    def as_dict(self) -> Dict[str, Union[str, int, None]]:
         return {
             "path": self.path,
             "module": self.module,
@@ -31,13 +40,20 @@ class Location(object):
             "character": self.character,
         }
 
-    def __hash__(self):
+    def __repr__(self) -> str:
+        return f"{self.path}:L{self.line}:{self.character}"
+
+    def __hash__(self) -> int:
         return hash((self.path, self.line, self.character))
 
-    def __eq__(self, other):
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, Location):
+            return False
         return self.path == other.path and self.line == other.line and self.character == other.character
 
-    def __lt__(self, other):
+    def __lt__(self, other: object) -> bool:
+        if not isinstance(other, Location):
+            raise ValueError
         if self.path == other.path:
             if self.line == other.line:
                 return (self.character or -1) < (other.character or -1)
@@ -45,20 +61,20 @@ class Location(object):
         return self.path < other.path
 
 
-class Message(object):
-    def __init__(self, source, code, location, message):
+class Message:
+    def __init__(self, source: str, code: str, location: Location, message: str):
         self.source = source
         self.code = code
         self.location = location
         self.message = message
 
-    def to_absolute_path(self, root):
+    def to_absolute_path(self, root: str):
         self.location.to_absolute_path(root)
 
-    def to_relative_path(self, root):
+    def to_relative_path(self, root: str):
         self.location.to_relative_path(root)
 
-    def as_dict(self):
+    def as_dict(self) -> Dict[str, Union[str, dict]]:
         return {
             "source": self.source,
             "code": self.code,
@@ -66,21 +82,32 @@ class Message(object):
             "message": self.message,
         }
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return "%s-%s" % (self.source, self.code)
 
-    def __eq__(self, other):
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, Message):
+            return False
         if self.location == other.location:
             return self.code == other.code
         else:
             return False
 
-    def __lt__(self, other):
+    def __lt__(self, other) -> bool:
         if self.location == other.location:
             return self.code < other.code
         return self.location < other.location
 
 
-def make_tool_error_message(filepath, source, code, message, line=0, character=0, module=None, function=None):
+def make_tool_error_message(
+    filepath: str,
+    source: str,
+    code: str,
+    message: str,
+    line: int = 0,
+    character: int = 0,
+    module: str = None,
+    function: str = None,
+) -> Message:
     location = Location(path=filepath, module=module, function=function, line=line, character=character)
     return Message(source=source, code=code, location=location, message=message)
