@@ -13,11 +13,6 @@ from prospector.message import Location, Message
 from prospector.tools import DEPRECATED_TOOL_NAMES
 from prospector.tools.utils import CaptureOutput
 
-__all__ = (
-    "Prospector",
-    "main",
-)
-
 
 class Prospector:
     def __init__(self, config: ProspectorConfig):
@@ -118,9 +113,9 @@ class Prospector:
                 sys.stderr.write(fatal.message)
                 sys.exit(2)
 
-            except Exception:  # pylint: disable=broad-except
+            except Exception as ex:
                 if self.config.die_on_tool_error:
-                    raise
+                    raise FatalProspectorException from ex
                 else:
                     loc = Location(self.config.workdir, None, None, None, None)
                     msg = (
@@ -216,15 +211,15 @@ def main():
     if config.exit_with_zero_on_success():
         # if we ran successfully, and the user wants us to, then we'll
         # exit cleanly
-        return 0
+        sys.exit(0)
 
     # otherwise, finding messages is grounds for exiting with an error
     # code, to make it easier for bash scripts and similar situations
-    # to know if there any errors have been found.
+    # to know if any errors have been found.
     if len(prospector.get_messages()) > 0:
-        return 1
-    return 0
+        sys.exit(1)
+    sys.exit(0)
 
 
 if __name__ == "__main__":
-    sys.exit(main())
+    main()
